Theory Guide
============

.. toctree::
    :maxdepth: 2
    :hidden:
    
    theory/contour
    theory/curvature
    theory/delaunay
    theory/improvement
    theory/octree
    theory/rays

.. note:: 
    This section is a work in progress.

The aim here is to provide explanations of how and why some of the important 
algorithms in MyMesh work. While the user guide and API reference are intended 
to show users how to *use* MyMesh, the theory guide is for helping users to 
*understand* MyMesh, and more specifically, the algorithms which it employs. Most 
users won't need this guide, but it aims to serve an educational purpose and 
lessen the "blackbox" nature of some important and complex meshing operations as
well as help to bridge the gap between the idea behind an algorithm and the 
implementation of that algorithm. Citations to the original authors and/or 
implementations of algorithms discussed in this guide will always be provided
when available. 
  